@@ -4,15 +4,21 @@ import os
 from pathlib import Path
 
 import vapoursynth as vs
-from vsexprtools import ExprOp, combine
-from vsexprtools.types import VSFunction
-from vsmask.edge import Kirsch, PrewittTCanny
-from vsrgtools import removegrain
+from vsexprtools import ExprOp, VSFunction, combine, expect_bits
 from vsutil import depth, disallow_variable_format, get_depth, get_peak_value, get_y, insert_clip, iterate
 
 from .misc import source as stgsource
 from .types import MaskCredit, Range
-from .utils import expect_bits
+
+__all__ = [
+    'adg_mask',
+    'perform_masks_credit',
+    'to_gray', 'manual_masking', 'get_manual_mask',
+    'tcanny', 'linemask',
+    'detail_mask',
+    'squaremask', 'replace_squaremask',
+    'freeze_replace_mask'
+]
 
 core = vs.core
 
@@ -94,38 +100,6 @@ def get_manual_mask(clip: vs.VideoNode, path: str, mapfunc: VSFunction | None =
     return mapfunc(maskclip) if mapfunc else maskclip.std.Binarize()
 
 
-def simple_detail_mask(
-    clip: vs.VideoNode, sigma: float | None = None, rad: int = 3, brz_a: float = 0.025, brz_b: float = 0.045
-) -> vs.VideoNode:
-    from lvsfunc import range_mask, scale_thresh
-
-    brz_a = scale_thresh(brz_a, clip)
-    brz_b = scale_thresh(brz_b, clip)
-
-    y = get_y(clip)
-
-    blur = y.bilateral.Gaussian(sigma) if sigma else y
-
-    mask_a = range_mask(blur, rad=rad).std.Binarize(brz_a)
-
-    mask_b = PrewittTCanny().edgemask(blur).std.Binarize(brz_b)
-
-    mask = core.akarin.Expr([mask_a, mask_b], 'x y max')
-
-    return removegrain(removegrain(mask, 22), 11).std.Limiter()
-
-
-def multi_detail_mask(clip: vs.VideoNode, thr: float = 0.015) -> vs.VideoNode:
-    general_mask = simple_detail_mask(clip, rad=1, brz_a=1, brz_b=24.3 * thr)
-
-    return combine([
-        combine([
-            simple_detail_mask(clip, brz_a=1, brz_b=2 * thr),
-            iterate(general_mask, core.std.Maximum, 3).std.Maximum().std.Inflate()
-        ], ExprOp.MIN), general_mask.std.Maximum()
-    ], ExprOp.MIN)
-
-
 def tcanny(clip: vs.VideoNode, thr: float) -> vs.VideoNode:
     msrcp = clip.bilateral.Gaussian(1).retinex.MSRCP([50, 200, 350], None, thr)
 
@@ -135,6 +109,16 @@ def tcanny(clip: vs.VideoNode, thr: float) -> vs.VideoNode:
 
 
 def linemask(clip_y: vs.VideoNode) -> vs.VideoNode:
+    try:
+        from vsscale import multi_detail_mask
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError('linemask: missing dependency `vsrgtools`')
+
+    try:
+        from vsmask.edge import Kirsch
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError('linemask: missing dependency `vsmask`')
+
     return combine([
         Kirsch().edgemask(clip_y),
         tcanny(clip_y, 0.000125),
@@ -145,34 +129,6 @@ def linemask(clip_y: vs.VideoNode) -> vs.VideoNode:
     ], ExprOp.ADD)
 
 
-def credit_mask(
-    clip: vs.VideoNode, ref: vs.VideoNode, thr: int,
-    blur: float | None = 1.65, prefilter: bool = True,
-    expand: int = 8
-) -> vs.VideoNode:
-    from vardefunc.mask import Difference
-
-    if blur is None or blur <= 0:
-        blur_src, blur_ref = clip, ref
-    else:
-        blur_src = clip.bilateral.Gaussian(blur)
-        blur_ref = ref.bilateral.Gaussian(blur)
-
-    ed_mask = Difference().creditless(
-        blur_src[0] + blur_src, blur_src, blur_ref,
-        start_frame=0, thr=thr, prefilter=prefilter
-    )
-
-    bits, credit_mask = expect_bits(ed_mask)
-    credit_mask = iterate(credit_mask, core.std.Minimum, 6)
-    credit_mask = iterate(credit_mask, lambda x: core.std.Minimum(x).std.Maximum(), 8)
-    if expand:
-        credit_mask = iterate(credit_mask, core.std.Maximum, expand)
-    credit_mask = credit_mask.std.Inflate().std.Inflate().std.Inflate()
-
-    return credit_mask if bits == 16 else depth(credit_mask, bits)
-
-
 # Stolen from Light by yours truly <3
 def detail_mask(
     clip: vs.VideoNode,
@@ -226,23 +182,29 @@ def squaremask(clip: vs.VideoNode, width: int, height: int, offset_x: int, offse
 def replace_squaremask(
     clipa: vs.VideoNode, clipb: vs.VideoNode, mask_params: tuple[int, int, int, int],
     ranges: Range | list[Range] | None = None,
-    blur_sigma: int | None = None, invert: bool = False
+    blur_sigma: float | None = None, invert: bool = False
 ) -> vs.VideoNode:
-    from lvsfunc import replace_ranges
+    try:
+        from lvsfunc import replace_ranges
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError('replace_squaremask: missing dependency `lvsfunc`')
 
-    assert clipa.format
-    assert clipb.format
+    try:
+        from vsrgtools import box_blur, gauss_blur
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError('replace_squaremask: missing dependency `vsrgtools`')
+
+    assert clipa.format and clipb.format
 
     mask = squaremask(clipb, *mask_params)
 
     if invert:
         mask = mask.std.InvertMask()
 
-    if blur_sigma is not None:
-        if clipa.format.bits_per_sample == 32:
-            mask = mask.bilateralgpu.Bilateral(blur_sigma)
-        else:
-            mask = mask.bilateral.Gaussian(blur_sigma)
+    if isinstance(blur_sigma, int):
+        mask = box_blur(mask, blur_sigma)
+    elif isinstance(blur_sigma, float):
+        mask = gauss_blur(mask, blur_sigma)
 
     merge = clipa.std.MaskedMerge(clipb, mask)
 
