@@ -1,27 +1,25 @@
 from __future__ import annotations
 
-from typing import Callable, Iterable, Protocol, Sequence
+from typing import Any, Callable, Sequence
 
 import vapoursynth as vs
-from vsexprtools import ExprOp, combine
-from vsexprtools.util import EXPR_VARS, normalise_planes
+from vsexprtools import EXPR_VARS, ComparatorFunc, ExprOp, PlanesT, combine, normalise_planes
+from vskernels import get_prop
 from vsutil import get_neutral_value
 
-from .types import T
-from .utils import get_prop
+__all__ = [
+    'bestframeselect',
+    'median_plane_value', 'mean_plane_value',
+    'weighted_merge'
+]
 
 core = vs.core
 
 
-class _CompFunction(Protocol):
-    def __call__(self, __iterable: Iterable[T], *, key: Callable[[T], float]) -> T:
-        ...
-
-
 def bestframeselect(
     clips: Sequence[vs.VideoNode], ref: vs.VideoNode,
     stat_func: Callable[[vs.VideoNode, vs.VideoNode], vs.VideoNode] = core.std.PlaneStats,
-    prop: str = 'PlaneStatsDiff', comp_func: _CompFunction = max, debug: bool | tuple[bool, int] = False
+    prop: str = 'PlaneStatsDiff', comp_func: ComparatorFunc = max, debug: bool | tuple[bool, int] = False
 ) -> vs.VideoNode:
     """
     Rewritten from https://github.com/po5/notvlc/blob/master/notvlc.py#L23.
@@ -56,7 +54,7 @@ def bestframeselect(
 
 
 def median_plane_value(
-    clip: vs.VideoNode, planes: int | Sequence[int] | None = None, single_out: bool = False, cuda: bool | None = None
+    clip: vs.VideoNode, planes: PlanesT = None, single_out: bool = False, cuda: bool | None = None
 ) -> vs.VideoNode:
     import numpy as np
 
@@ -124,6 +122,96 @@ def median_plane_value(
     return outclip.resize.Point(clip.width, clip.height)
 
 
+def mean_plane_value(
+    clip: vs.VideoNode, excl_values: list[float] | list[list[float]] | None = None, planes: PlanesT = None,
+    single_out: bool = False, cuda: bool | None = None, prop: str = '{plane}Mean'
+) -> vs.VideoNode:
+    import numpy as np
+
+    try:
+        import cupy
+        cuda_available = True
+    except ImportError:
+        cupy = None
+        cuda_available = False
+
+    assert clip.format
+
+    do_cuda = cuda_available if cuda is None else cuda
+
+    npp = cupy if do_cuda and cuda_available and clip.height > 720 and clip.width > 1024 else np
+
+    norm_planes = normalise_planes(clip, planes)
+
+    n_planes = len(norm_planes)
+
+    color_fam_str = 'YUV' if clip.format.color_family == vs.YUV else 'RGB'
+
+    prop_name = prop.format(plane=color_fam_str)
+    plane_kwords = [prop.format(plane=plane) for plane in color_fam_str]
+
+    if not excl_values:
+        def _get_mean(farr: Any, plane: int) -> Any:
+            return float(npp.mean(farr))
+    elif isinstance(excl_values[0], (int, float)):
+        excl_cut = excl_values[1:]
+
+        def _get_mean(farr: Any, plane: int) -> Any:
+            cond = farr != excl_values[0]  # type: ignore
+
+            for val in excl_cut:
+                cond = cond & (farr != val)
+
+            selected = farr[cond]
+
+            mean = npp.mean(selected)
+
+            return float(mean)
+    else:
+        excl_cut = [excl[1:] for excl in excl_values]  # type: ignore
+
+        def _get_mean(farr: Any, plane: int) -> Any:
+            cond = farr != excl_values[plane][0]  # type: ignore
+
+            for val in excl_cut[plane]:  # type: ignore
+                cond = cond & (farr != val)
+
+            selected = farr[cond]
+
+            mean = npp.mean(selected)
+
+            return float(mean)
+
+    if single_out:
+        def _mean_excl_modify_frame(f: vs.VideoFrame, n: int) -> vs.VideoFrame:
+            fdst = f.copy()
+
+            means = []
+
+            for plane in norm_planes:
+                farr = npp.asarray(f[plane])
+                farr = npp.reshape(farr, farr.shape[0] * farr.shape[1])
+
+                means.append(_get_mean(farr, plane))
+
+            fdst.props.update(**{prop_name: sum(means) / n_planes})
+
+            return fdst
+    else:
+        def _mean_excl_modify_frame(f: vs.VideoFrame, n: int) -> vs.VideoFrame:
+            fdst = f.copy()
+
+            for plane in norm_planes:
+                farr = npp.asarray(f[plane])
+                farr = npp.reshape(farr, farr.shape[0] * farr.shape[1])
+
+                fdst.props.update(**{plane_kwords[plane]: _get_mean(farr, plane)})
+
+            return fdst
+
+    return clip.std.ModifyFrame(clip, _mean_excl_modify_frame)
+
+
 def weighted_merge(*weighted_clips: tuple[vs.VideoNode, float]) -> vs.VideoNode:
     assert len(weighted_clips) <= len(EXPR_VARS), ValueError("weighted_merge: Too many clips!")
 
