@@ -6,9 +6,8 @@ from math import cos, degrees, floor, pi, sin
 from typing import Any, NamedTuple, Sequence, SupportsFloat
 
 import vapoursynth as vs
-from vsexprtools import ExprOp, expr
-from vsexprtools.types import StrList, VSFunction
-from vskernels import BSpline, Catrom, Point
+from vsexprtools import ExprOp, StrList, VSFunction, norm_expr
+from vskernels import BSpline, Catrom, Point, get_prop
 from vsutil import (
     disallow_variable_format, disallow_variable_resolution, fallback, get_depth, get_neutral_value, get_peak_value,
     get_subsampling, insert_clip, scale_value
@@ -17,7 +16,13 @@ from vsutil import (
 from .easing import ExponentialEaseIn, F_Easing
 from .transitions import crossfade
 from .types import Range
-from .utils import get_color_range, get_prop
+
+__all__ = [
+    'Tweak',
+    'tweak_clip', 'multi_tweak',
+    'BalanceMode', 'WeightMode', 'Override',
+    'auto_balance', 'bbmod_fast'
+]
 
 core = vs.core
 
@@ -36,7 +41,7 @@ def tweak_clip(
 
     bits = get_depth(clip)
 
-    range_in = fallback(range_in, get_color_range(clip))
+    range_in = fallback(range_in, get_prop(clip, '_ColorRange', int, vs.ColorRange, vs.RANGE_LIMITED))
     range_out = fallback(range_out, range_in)
 
     sv_args_out = dict[str, Any](
@@ -101,9 +106,7 @@ def tweak_clip(
         if clamp and range_out:
             yexpr.extend(StrList([luma_min, ExprOp.MAX, luma_max, ExprOp.MIN]))
 
-    tclip = core.std.ShufflePlanes([
-        expr(clips, yexpr, 0), expr(clips, cexpr, [1, 2])
-    ], [0, 1, 2], vs.YUV)
+    tclip = norm_expr(clips, (yexpr, cexpr))
 
     return post(tclip) if callable(post) else tclip
 
